AutoArchive._application.archiving.actions — AutoArchive Developer Manual (ver. 2.0.6)

# AutoArchive._application.archiving.actions

## Modules

### action_utils

class AutoArchive._application.archiving.actions.action_utils.ActionUtils(componentUi, applicationContext, serviceAccessor: ServiceAccessor)

  Bases: `object`

  getArchiveSpecsForProcessing(selectedArchiveSpecs)
  getOrphanedArchives(archiveSpecs)
  getValidArchiveNames(archiveSpecs)
  property actionResult: ActionResult
  property archiving: _Archiving
  property commandExecutor: _CommandExecutor
  property componentUi
  property configuration

### create_action

class AutoArchive._application.archiving.actions.create_action.CreateAction(actionUtils: ActionUtils, selectedArchiveSpecs)

  Bases: `Action`

  executeAction_() → bool
  handleResult_(actionResult: ActionResult) → None

### list_action

class AutoArchive._application.archiving.actions.list_action.ListAction(actionUtils: ActionUtils, selectedArchiveSpecs)

  Bases: `Action`

  executeAction_() → bool

### purge_action

class AutoArchive._application.archiving.actions.purge_action.PurgeAction(actionUtils: ActionUtils, selectedArchiveSpecs)

  Bases: `Action`

  executeAction_() → bool